Security Advisories (10)
CPANSA-Mojolicious-2022-03 (2022-12-10)

Mojo::DOM did not correctly parse <script> tags.

CPANSA-Mojolicious-2021-02 (2021-06-01)

Small sessions could be used as part of a brute-force attack to decode the session secret.

CVE-2021-47208 (2021-03-16)

A bug in format detection can potentially be exploited for a DoS attack.

CVE-2018-25100 (2018-02-13)

Mojo::UserAgent::CookieJar leaks old cookies because of the missing host_only flag on empty domain.

CPANSA-Mojolicious-2015-01 (2015-02-02)

Directory traversal on Windows

CPANSA-Mojolicious-2018-03 (2018-05-19)

Mojo::UserAgent was not checking peer SSL certificates by default.

CVE-2020-36829 (2020-11-10)

Mojo::Util secure_compare can leak the string length. By immediately returning when the two strings are not the same length, the function allows an attacker to guess the length of the secret string using timing attacks.

CPANSA-Mojolicious-2018-02 (2018-05-11)

GET requests with embedded backslashes can be used to access local files on Windows hosts

CPANSA-Mojolicious-2014-01 (2014-10-07)

Context sensitivity of method param could lead to parameter injection attacks.

CVE-2024-58134 (2025-05-03)

Mojolicious versions from 0.999922 for Perl uses a hard coded string, or the application's class name, as a HMAC session secret by default. These predictable default secrets can be exploited to forge session cookies. An attacker who knows or guesses the secret could compute valid HMAC signatures for the session cookie, allowing them to tamper with or hijack another user's session.

NAME

Mojo::Reactor::Poll - Low-level event reactor with poll support

SYNOPSIS

use Mojo::Reactor::Poll;

# Watch if handle becomes readable or writable
my $reactor = Mojo::Reactor::Poll->new;
$reactor->io($handle => sub {
  my ($reactor, $writable) = @_;
  say $writable ? 'Handle is writable' : 'Handle is readable';
});

# Change to watching only if handle becomes writable
$reactor->watch($handle, 0, 1);

# Add a timer
$reactor->timer(15 => sub {
  my $reactor = shift;
  $reactor->remove($handle);
  say 'Timeout!';
});

# Start reactor if necessary
$reactor->start unless $reactor->is_running;

DESCRIPTION

Mojo::Reactor::Poll is a low-level event reactor based on IO::Poll.

EVENTS

Mojo::Reactor::Poll inherits all events from Mojo::Reactor.

METHODS

Mojo::Reactor::Poll inherits all methods from Mojo::Reactor and implements the following new ones.

again

$reactor->again($id);

Restart active timer.

io

$reactor = $reactor->io($handle => sub {...});

Watch handle for I/O events, invoking the callback whenever handle becomes readable or writable.

is_running

my $bool = $reactor->is_running;

Check if reactor is running.

one_tick

$reactor->one_tick;

Run reactor until an event occurs or no events are being watched anymore. Note that this method can recurse back into the reactor, so you need to be careful.

recurring

my $id = $reactor->recurring(0.25 => sub {...});

Create a new recurring timer, invoking the callback repeatedly after a given amount of time in seconds.

remove

my $bool = $reactor->remove($handle);
my $bool = $reactor->remove($id);

Remove handle or timer.

reset

$reactor->reset;

Remove all handles and timers.

start

$reactor->start;

Start watching for I/O and timer events, this will block until "stop" is called or no events are being watched anymore.

stop

$reactor->stop;

Stop watching for I/O and timer events.

timer

my $id = $reactor->timer(0.5 => sub {...});

Create a new timer, invoking the callback after a given amount of time in seconds.

watch

$reactor = $reactor->watch($handle, $readable, $writable);

Change I/O events to watch handle for with true and false values. Note that this method requires an active I/O watcher.

SEE ALSO

Mojolicious, Mojolicious::Guides, http://mojolicio.us.